import {
    ApiModel
} from "../../utils/api";
const _Http = new ApiModel();
Page({
    /**
     * 页面的初始数据
     */
    data: {
        active: 0, //tabs选中下标
        pageNumber: 1, //请求页号
        pageTotal: 1, //总页码
        productList: [], //产品列表
        loadMore: true, //加载更多
        fisadministrator: false, //是否主账号
        searchContent: "", //模糊搜索字段
        onShowFlush: false, //是否触发onShow刷新
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        this.gettingData(this.data.active);
        this.setData({
            fisadministrator: (wx.getStorageSync('userData').fisadministrator == 1) ? true : false
        })
    },
    /* 搜索查询 */
    searchQuery(value) {
        if (value.detail == this.data.searchContent) return;
        this.gettingData(this.data.active, value.detail)
        this.setData({
            searchContent: value.detail
        })
    },
    /* 滑动区域上拉触底 */
    scrolltolower() {
        if (this.data.loadMore) {
            if (this.data.pageNumber < this.data.pageTotal) {
                this.setData({
                    pageNumber: this.data.pageNumber + 1
                })
                this.gettingData(this.data.active)
            }
            this.setData({
                loadMore: false
            })
        }
    },
    /* tabs 切换事件 */
    tabsChange(e) {
        const {
            index
        } = e.detail;
        this.setData({
            active: e.detail.index,
            pageNumber: 1, //请求页号
            pageTotal: 1, //总页码
            loadMore: true, //加载更多
            productList: [],
        })
        this.gettingData(index, this.data.searchContent)
    },
    /* 获取数据 */
    gettingData(index, value) {
        let where = {
            "condition": "",
            "fisonsale": ""
        };
        //请求类型
        if (index == 1) {
            where.fisonsale = 1;
        } else if (index == 2) {
            where.fisonsale = 0;
        }
        //模糊搜索
        if (value) {
            where.condition = value
        };
        /* 发送请求 */
        _Http.basic({
            "accesstoken": wx.getStorageSync('userData').token,
            "classname": "customer.products.products",
            "method": "query_productsList",
            "content": {
                "getdatafromdbanyway": true,
                "pageNumber": this.data.pageNumber,
                "pageSize": 20,
                "where": where
            }
        }).then(res => {
            if (res.msg != '成功') return wx.showToast({
                title: res.data,
                icon: "none"
            })
            /* 拼接列表 */
            let productList = [];
            if (this.data.pageNumber != 1) {
                productList = this.data.productList.concat(res.data);
            } else {
                productList = res.data;
            }
            this.setData({
                productList,
                loadMore: true, //加载更多
                pageTotal: res.pageTotal
            })
        })
    },
    /* 产品信息修改 */
    changeProductMessage(e) {
        const {
            index
        } = e.currentTarget.dataset;
        const data = JSON.stringify(this.data.productList[index])
        //刷新页面
        this.isOnShow();
        wx.navigateTo({
            url: '/pages/productManagement/change?data=' + data,
        })
    },
    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },
    //允许onshow刷新
    isOnShow() {
        console.log("调用")
        this.setData({
            onShowFlush: true
        })
    },
    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {
        //重新获取数据列表
        if (this.data.onShowFlush) {
            this.gettingData(this.data.active)
            this.setData({
                onShowFlush: false
            })
        }
    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})